import { PromiseWithSubtest, TapPlugin, TestBase, TestBaseOpts } from '@tapjs/core';
import type { Test, TestOpts } from '@tapjs/test';
export interface FilterOptions extends TestBaseOpts {
    /**
     * Set to true to run in contexts where `runOnly` is set
     */
    only?: boolean;
    /**
     * Only run subtests marked with { only: true }
     */
    runOnly?: boolean;
    /**
     * only run subtests whose name matches the supplied pattern.
     * Provide an array of strings/regexps to match down the test
     * heirarchy.
     */
    grep?: string | RegExp | (string | RegExp)[];
    /**
     * only run tests that DON'T match the pattern provided in `grep`
     */
    grepInvert?: boolean;
}
export declare class Filter {
    #private;
    constructor(t: TestBase, opts: FilterOptions);
    only(name: string, extra: TestOpts, cb: (t: Test) => any): PromiseWithSubtest<Test>;
    only(name: string, cb: (t: Test) => any): PromiseWithSubtest<Test>;
    only(extra: TestOpts, cb: (t: Test) => any): PromiseWithSubtest<Test>;
    only(cb: (t: Test) => any): PromiseWithSubtest<Test>;
}
export declare const plugin: TapPlugin<Filter, FilterOptions>;
export declare const config: {
    only: {
        type: string;
        short: string;
        description: string;
    };
    grep: {
        type: string;
        multiple: boolean;
        hint: string;
        short: string;
        description: string;
    };
    invert: {
        type: string;
        short: string;
        description: string;
    };
    'no-invert': {
        type: string;
        short: string;
        description: string;
    };
};
//# sourceMappingURL=index.d.ts.map